# Chat History

User Prompt | LLM Answer | Size | # of History | Chat ID | Platform | Provider | Model
--- | --- | --- | --- | --- | --- | --- | ---
{% for chat in chats %}
{{ chat.get('user_prompt', '')[:128] }}{% if chat.get('user_prompt', '')|length > 128 %}...{% endif %} | {{ chat.get('llm_answer', '')[:128] }}{% if chat.get('llm_answer', '')|length > 128 %}...{% endif %} | {{ chat.get('user_prompt', '') | length }} / {{ chat.get('llm_answer', '') | length }} | {{ chat.get('histories', [])|length }} | {{ chat.get('chat_thread_id') }} | {{ chat.get('user_data', {}).get('selected_platform', '') }} | {{ chat.get('user_data', {}).get('selected_provider', '') }} | {{ chat.get('user_data', {}).get('selected_model', '') }}
{% endfor %}